Pull real-time species stock data directly from StockSMART API
Source:R/get_species_stock_data.R
get_species_stock_data.RdPulls data defined by stock directly to obtain current data. For those who don't want to reinstall the package to get most recent data