Reference points, contact info, assessment metadata for USA assessed stocks
Source:R/data-stockAssessmentSummary.R
stockAssessmentSummary.RdstockAssessmentSummary is deprecated. It will continue to receive updates for while. From v1.0.0 it will not be used in any of the supporting functions.
Camel case naming is being replaced by snake case. Please use stock_assessment_summary instead since this data set is used in all supporting functions.
Stock assessment metadata and reference points for species found in waters of the USA. Data is provided for actively managed stocks of a federal Fisheries Management Plan (FMP). Stocks solely managed by US States are not provided. For a description of all variables please refer to the Stock SMART data dictionary https://apps-st.fisheries.noaa.gov/stocksmart/StockSMART_DataDictionary.pdf
Format
A data frame with n rows and m variables
- Stock Name
- Stock ID
Unique Stock identifier
- Assessment ID
Unique Assessment identifer
- Jurisdiction
- FMP
- Science Center
- Regional Ecosystem
- FSSI Stock?
- ITIS Taxon Serial Number
- Scientific Name
- Common Name
- Stock Area
- Assessment Year
- Assessment Month
- Last Data Year
- Assessment Type
Joining of Update Type and Assessment Type: Describes the level of assessment effort
- Review Result
- Assessment Model
- Model Version
- Lead Lab
- Citation
- Final Assessment Report 1
- Final Assessment Report 2
- Point of Contact
- Life History Data
- Abundance Data
- Catch Data
- Assessment Level
- Assessment Frequency
- Model Category
- Catch Input Data
- Abundance Input Data
- Biological Input Data
- Ecosystem Linkage
- Composition Input Data
- F Year
- Estimated F
- F Unit
- F Basis
- Flimit
- Flimit Basis
- Fmsy
- Fmsy Basis
- F/Flimit
- F/Fmsy
- Ftarget
- Ftarget Basis
- F/Ftarget
- B Year
- Estimated B
- B Unit
- B Basis
- Blimit
- Blimit Basis
- Bmsy
- Bmsy Basis
- B/Blimit
- B/Bmsy
- MSY
- MSY Unit
Data download
The data were downloaded from Stock SMART - Status, Management, Assessments & Resource Trends.
For Manual download:
Click the "Download Data" module
Select data to download (dropdown) -> Assessment Summary Data
Select full range of years from Start Calendar Year- End Calendar Year
Click Search Stocks button
Click Select All Stocks button
Click Select All Fields button
Click Download button
Download all Parts
See also
Other stockAssessments:
stockAssessmentData,
stock_assessment_data,
stock_assessment_summary